@@ -54,9 +54,9 @@ class SerieTemporal(ApiBiuld):
                     flow.append(month.find(value).text)
                 except AttributeError:
                     flow.append(None)
-            series.append(pd.Series(flow, index=date_idx, name=code, dtype='float64'))
+            series.append(pd.Series(flow, index=date_idx, name=code.zfill(8), dtype='float64'))
         try:
             data_flow = pd.DataFrame(pd.concat(series))
         except ValueError:
-            data_flow = pd.DataFrame(pd.Series(name=self.params['codEstacao'], dtype='float64'))
+            data_flow = pd.DataFrame(pd.Series(name=self.params['codEstacao'].zfill(8), dtype='float64'))
         return data_flow
